/*
 * Copyright 2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * This package contains {@link org.gradle.internal.component.resolution.failure.interfaces.ResolutionFailure ResolutionFailure}s types
 * that exist to categorize types of failure conditions that can occur during dependency resolution and package contextual information
 * specific to each type of failure.
 */
@NullMarked
package org.gradle.internal.component.resolution.failure.type;

import org.jspecify.annotations.NullMarked;
